@@ -23,4 +23,4 @@ NULL
 
 ## A fix to let CRAN check NOTEs diasappear for non-standard-evaluation used
 ## cf. http://stackoverflow.com/questions/9439256/how-can-i-handle-r-cmd-check-no-visible-binding-for-global-variable-notes-when
-globalVariables(c(".", "name", "id", "iid", "rel"))
+globalVariables(c("name", "id", "iid", "rel", "."))
